blender/extern/quadriflow/patches
Ray Molenkamp 18a01ebc6b CMake: Remove ceres and eigen from /extern
This change reduces compile time:

```
before: 648.4 s weighted time (15645.9 s elapsed time sum, 24.1x parallelism)
after : 613.6 s weighted time (14110.1 s elapsed time sum, 23.0x parallelism)
-----------------------------------------------------------------------------
Diff  : -34.8 s                -1535.8
```

We now also bundle less libraries within the Blender code base.
2026-02-05 23:10:02 +01:00
..
blender.patch CMake: Remove ceres and eigen from /extern 2026-02-05 23:10:02 +01:00
boykov_kolmogorov_max_flow.hpp Fix #136593, #136641: Quadriflow remesh gets stuck on Windows 2025-03-28 19:25:56 +01:00